@@ -7,10 +7,10 @@ from dbt.adapters.firebolt.connections import (
 from dbt.adapters.firebolt.impl import FireboltAdapter
 from dbt.include import firebolt
 
-__version__ = "1.2.0"
+__version__ = "1.3.0"
 
 Plugin = AdapterPlugin(
-    adapter=FireboltAdapter,
+    adapter=FireboltAdapter,  # type: ignore
     credentials=FireboltCredentials,
     include_path=firebolt.PACKAGE_PATH,
 )
